/// <reference types="node" />
import * as keyChainImpls from './keyChainImpl';
/**
 * Crypto class for SFDX.
 * @param packageDotJson - Override object for package.json properties. Used for unit testing.
 * @constructor
 */
declare class Crypto {
    [property: string]: any;
    constructor(_keychainImpls?: typeof keyChainImpls);
    /**
     * Initialize any crypto dependencies. In this case we need to generate an encryption key.
     * @param retryStatus - A string message to track retries
     * @returns {*}
     */
    init(retryStatus?: any, platform?: NodeJS.Platform): any;
    /**
     * Encrypts text.
     * @param text - The text to encrypt.
     * @returns {undefined|String} - If enableTokenEncryption is set to false or not defined in package.json then the text
     * is simply returned unencrypted.
     */
    encrypt(text: any): any;
    /**
     * Decrypts text.
     * @param text - The text to decrypt.
     * @returns {undefined|String} - If enableTokenEncryption is set to false or not defined in package.json then the text
     * is simply returned. The is then assumed to be unencrypted.
     */
    decrypt(text: any): any;
    close(): void;
}
export = Crypto;
