/**
 * contents for platform type
 * @type {{WINDOWS: string, DARWIN: string, LINUX: string, GENERIC_UNIX: string}}
 */
export declare const platforms: {
    WINDOWS: string;
    DARWIN: string;
    LINUX: string;
    GENERIC_UNIX: string;
    GENERIC_WINDOWS: string;
};
/**
 * private helper to validate that a program exists on the files system and is executable
 * @param programPath - the absolute path of the program
 * @param fsIfc - the file system interface
 * @param isExeIfc - executable validation function
 * @private
 */
export declare const validateProgram: (programPath: any, fsIfc: any, isExeIfc: any) => void;
declare class KeychainAccess {
    [property: string]: any;
    /**
     * abstract prototype for general cross platform keychain interaction
     * @param osImpl - the platform impl for (linux, darwin, windows)
     * @param fsIfc - the file system interface
     * @constructor
     */
    constructor(osImpl: any, fsIfc: any);
    validateProgram(): void;
    /**
     * gets a password using the native program for credential management.
     * @param opts - options for the credential lookup
     * @param fn - callback function (err, password)
     * @param retryCount - used internally to track the number of retries for getting a password out of the keychain.
     */
    getPassword(opts: any, fn: any, retryCount: any): void;
    /**
     * sets a password using the native program for credential management.
     * @param opts - options for the credential lookup
     * @param fn - callback function (err, password)
     */
    setPassword(opts: any, fn: any): void;
}
export declare const windows: KeychainAccess;
export declare const linux: KeychainAccess;
export declare const darwin: KeychainAccess;
declare class GenericKeychainAccess {
    getSecretFile(): string;
    isValidFileAccess(cb: any): void;
    getPassword(opts: any, fn: any): void;
    setPassword(opts: any, fn: any): void;
}
declare class GenericUnixKeychainAccess extends GenericKeychainAccess {
    isValidFileAccess(cb: any): void;
}
declare class GenericWindowsKeychainAccess extends GenericKeychainAccess {
}
export declare const generic_unix: GenericUnixKeychainAccess;
export declare const generic_windows: GenericWindowsKeychainAccess;
export {};
