"use strict";
/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataRecordGetCommand = void 0;
const Display = require("../force-cli/force-cli-display");
const Config = require("../force-cli/force-cli-config");
const DataRecordUtils = require("./dataRecordUtils");
class DataRecordGetCommand {
    async execute(context) {
        DataRecordUtils.validateIdXorWhereFlags(context);
        context.ux.startSpinner('Getting Record');
        const conn = await Config.getActiveConnection(context);
        const sobjectid = await DataRecordUtils.retrieveId(conn, context);
        const record = context.flags.usetoolingapi
            ? await conn.tooling.retrieve(context.flags.sobjecttype, sobjectid)
            : await conn.sobject(context.flags.sobjecttype).retrieve(sobjectid);
        context.ux.stopSpinner();
        Display.record(record);
        return record;
    }
}
exports.DataRecordGetCommand = DataRecordGetCommand;

//# sourceMappingURL=dataRecordGetCommand.js.map
