"use strict";
/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const srcDevUtil = require("../core/srcDevUtil");
const ActiveScratchOrgDeleteApi = require("./activeScratchOrgDeleteApi");
const Messages = require("../messages");
const messages = Messages();
class OrgDeleteCommand {
    async execute(context) {
        const activeScratchOrgDeleteApi = new ActiveScratchOrgDeleteApi();
        const orgData = await this.org.getConfig();
        try {
            await activeScratchOrgDeleteApi.doDelete(this.org, context.targetdevhubusername);
        }
        catch (err) {
            if (err.name === 'attemptingToDeleteExpiredOrDeleted') {
                this.alreadyDeleted = true;
            }
            else {
                // Includes the "insufficientAccessToDelete" error.
                throw err;
            }
        }
        await this.org.deleteConfig();
        return {
            orgId: orgData.orgId,
            username: orgData.userName
        };
    }
    async validate(context) {
        this.org = context.org;
        const fixedContext = srcDevUtil.fixCliContext(context);
        this.username = fixedContext.targetusername;
        if (!this.username) {
            this.username = context.org.name;
        }
        return fixedContext;
    }
    getHumanSuccessMessage() {
        if (this.alreadyDeleted) {
            return messages.getMessage('deleteOrgConfigOnlyCommandSuccess', this.username);
        }
        else {
            return messages.getMessage('deleteOrgCommandSuccess', this.username);
        }
    }
}
module.exports = OrgDeleteCommand;

//# sourceMappingURL=activeScratchOrgDeleteCommand.js.map
