import VarargsCommand from '../core/varargsCommand';
import { StatusResult } from '@salesforce/core';
import { JsonMap } from '@salesforce/ts-types';
import { Duration } from '@salesforce/kit';
/**
 * constructs a create command helper
 * @param force - the force api
 * @constructor
 */
declare class OrgCreateCommand extends VarargsCommand {
    static readonly SNAPSHOT_UNSUPPORTED_OPTIONS: string[];
    static DEFAULT_POLLING_FREQ: Duration;
    private workspaceType;
    private force;
    private org;
    private scratchOrgInfoId;
    private cliContext;
    constructor();
    /**
     * secondary validation from the cli interface. this is a protocol style function intended to be represented by other
     * commands
     * @param context - this cli context
     * @returns {Promise}
     */
    validate(context: any): Promise<any>;
    streamProcessor(message: JsonMap): StatusResult;
    /**
     * This performs three functions.
     * 1) Setup a stream listener for a OrgLifecycleNotification
     * 2) Prepares the cli input for the scratchOrgInfo request
     * 3) Calls the server to create a scratchOrgInfo
     * @returns {Promise}
     * @private
     */
    private signupOrgWithStreaming;
    private signupOrgWithPolling;
    /**
     * executes the command. this is a protocol style function intended to be represented by other commands.
     * @param cliContext - the cli context
     * @param stdinValues - param values obtained from stdin
     * @returns {Promise}
     */
    execute(cliContext: any, stdinValues: any): Promise<any>;
    _getScratchOrgInfo(masterOrg: any, context: any): Promise<any>;
    parseSignupErrorCode(err: any): any;
    private updateRevisionCounterToZero;
    /**
     * returns a human readable message for cli output
     * @param org - the result oif execute
     * @returns {string}
     */
    getHumanSuccessMessage(org: any): any;
    /**
     * returns a human readable error message for cli output
     * @returns {string}
     */
    getHumanErrorMessage(err: any): any;
}
export = OrgCreateCommand;
