"use strict";
/*
 * Copyright (c) 2018, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
// Node
const util = require("util");
// Local
const Messages = require("../messages");
const messages = Messages();
const PackageVersionCreateRequestApi = require("./packageVersionCreateRequestApi");
const logger = require("../core/logApi");
const pkgUtils = require("./packageUtils");
class PackageVersionCreateRequestListCommand {
    constructor() {
        this.logger = logger.child('package:version:create:list');
    }
    execute(context) {
        return this._execute(context).catch(err => {
            // TODO
            // until package2 is GA, wrap perm-based errors w/ 'contact sfdc' action (REMOVE once package2 is GA'd)
            throw pkgUtils.applyErrorAction(err);
        });
    }
    _execute(context) {
        this.packageVersionCreateRequestApi = new PackageVersionCreateRequestApi(context.org.force, context.org);
        return this.packageVersionCreateRequestApi.list(context.flags).then(results => {
            this.cnt = util.isArray(results) ? results.length : 0;
            return results;
        });
    }
    /**
     * indicates that the human readable message should be tabular
     * @returns {[{}...]}
     */
    getColumnData() {
        this.logger.styledHeader(this.logger.color.blue(`Package Version Create Requests  [${this.cnt || 0}]`));
        const columnData = [
            { key: 'Id', label: 'Id' },
            {
                key: 'Status',
                label: messages.getMessage('status', [], 'package_version_create_list')
            },
            {
                key: 'Package2Id',
                label: messages.getMessage('packageId', [], 'package_version_create_list')
            },
            {
                key: 'Package2VersionId',
                label: messages.getMessage('packageVersionId', [], 'package_version_create_list')
            },
            {
                key: 'SubscriberPackageVersionId',
                label: messages.getMessage('subscriberPackageVersionId', [], 'package_version_create_list')
            },
            {
                key: 'Tag',
                label: messages.getMessage('tag', [], 'package_version_create_list')
            },
            {
                key: 'Branch',
                label: messages.getMessage('branch', [], 'package_version_create_list')
            },
            { key: 'CreatedDate', label: 'Created Date' }
        ];
        return columnData;
    }
}
module.exports = PackageVersionCreateRequestListCommand;

//# sourceMappingURL=packageVersionCreateRequestListCommand.js.map
